@@ -1,15 +1,14 @@
 ;;; system-packages.el --- functions to manage system packages -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2016-2018 J. Alexander Branham
+;; Copyright (C) 2016-2019 Free Software Foundation, Inc.
 
 ;; Author: J. Alexander Branham <alex.branham@gmail.com>
 ;; Maintainer: J. Alexander Branham <alex.branham@gmail.com>
 ;; URL: https://gitlab.com/jabranham/system-packages
 ;; Package-Requires: ((emacs "24.3"))
-;; Version: 1.0.10
+;; Version: 1.0.11
 
-
-;; This file is not part of GNU Emacs.
+;; This file is part of GNU Emacs.
 
 ;;; License:
 ;;
@@ -161,7 +160,7 @@
           (remove-orphaned . "apt-get autoremove")
           (list-installed-packages . "dpkg -l")
           (list-installed-packages-all . "dpkg -l")
-          (list-dependencies-of . "apt-cache deps")
+          (list-dependencies-of . "apt-cache depends")
           (noconfirm . "-y")))
     (aptitude .
               ((default-sudo . t)
@@ -295,10 +294,10 @@ The key is the package manager and values (usually) commands.")
           (setq manager nil))))
     (car manager))
   "Symbol containing the package manager to use.
-
 See `system-packages-supported-package-managers' for a list of
 supported software.  Tries to be smart about selecting the
-default."
+default.  If you change this value, you may also want to change
+`system-packages-use-sudo'."
   :type '(choice
           (const guix)
           (const nix-env)
@@ -343,8 +342,8 @@ of passing additional arguments to the package manager."
       (error (format "%S not supported in %S" action system-packages-package-manager)))
     (unless (listp command)
       (setq command (list command)))
-    (setq command (mapconcat 'identity command " && "))
-    (setq command (mapconcat 'identity (list command pack) " "))
+    (setq command (mapconcat #'identity command " && "))
+    (setq command (mapconcat #'identity (list command pack) " "))
     (when noconfirm
       (setq args (concat args (and pack " ") noconfirm)))
     (concat command args)))
